% Master script that includes all scripts used to prepare the matrices used
% in my Master thesis.
% 
% Author: Kjartan Steen-Olsen
clear all
clc

% Starting timer:
t1 = clock;

%% Running preparatory scripts (generates basic A, L, s, v, and y):
% S_ESA
% Emissions_inserter
% disag_el_emissions
% MainKjartan
% new_s_el
load MainK_results
load frame
clear Z %Y
L = inv(eye(2077)-A);
%% Characterization matrix:
C = [0.023,1,0.296,0,0,0,0,0;0,0,0,0,0.5,0,0,1.2];
%GWP (ktons CO2-eq), AP (tons SO2-eq) for CH4, CO2, N2O, NH3, NOx, CO, NMVOC, SOx
s_temp = s;
s_temp(isnan(s_temp)) = 0;
Cs = C*s_temp;

%% Test:
% test

%% Base scenario modeling:
scale_y                                                                     % Script that scales y according to GDP projections, creating Y's for four years (2000, 2010, 2020, 2030)
y_SB_vector = squeeze(sum(y_SB,2));                                         % Total annual final demand for the four years
clear y_SB

for i=1:4
    x_SB(:,i) = inv(eye(size(A,1))-A)*y_SB_vector(:,i);
    x_SB(x_SB<1e-6) = 1e-6;
    Z_SB(:,:,i) = A*diag(x_SB(:,i));                                        % Z matrices (annual flows) for the four years
    e(:,i) = Cs*x_SB(:,i);
    E_dir(:,i) = diag(Cs(1,:))*x_SB(:,i);
    E_Z = diag(Cs(1,:))*Z_SB(:,:,i);
    E_Z_f(1:2077,1:31*3,i) =...
        E_Z(:,[65:3*31+64]+(67-3)*floor([0:3*31-1]/3));
    clear E_Z
end

% Aluminium trade flows:
for n = 1:4
    for i = 1:31
        for j=1:31
            trade_BL(i,j,n) = sum(Z_SB(67*(i-1)+65,67*(j-1)+1:67*j,n))/...
                (newsectors_basis(1).price(i)/1000);                        % Flows converted to ktons of aluminium
        end
    end
end

% Emissions due to Al production:
y_Al = zeros(2077,4);
y_Al(65:67:end,:) = x_SB(65:67:end,:); %y_Al is a 'f.d.' vector containing only the total output of Al
L_Al = L;
L_Al(:,65:67:end) = L_Al(:,65:67:end)*inv(diag(diag(L(65:67:end,65:67:end))));
for i = 1:4
    x_Al(:,i) = L_Al*y_Al(:,i);
end
GWP_Al_BL = diag(Cs(1,:))*x_Al;
AP_Al_BL = diag(Cs(2,:))*x_Al;


%% Scenario 1/2: All new aluminium production in CN (2: NO Al-->0)
AlC = 67*24+65;                                                             % Sector number of Chinese aluminium sector (1673)

sn = input('Please choose scenario 1 or 2: ');

% Calculating total increase in global Aluminium sales - in tons:
AluS = Z_SB(65:67:end,:,:);                                                 % Interindustrial sales of aluminium for each year
for i=1:4
    AluS_ph(:,:,i) = inv(diag(newsectors_basis(1).price'/1e6))*AluS(:,:,i); % Converting to physical units..
end
AluS_ph_tot = sum(AluS_ph);                                                 % Global totals

for n=2:4
diffS_ph = squeeze(AluS_ph_tot(:,:,n) - AluS_ph_tot(:,:,1));                % Calculating change relative to base year
diffS = diffS_ph*newsectors_basis(1).price(25)/1e6;                         % Converting to monetary equivalents (Chinese prices)

Z_SC_n_temp = squeeze(Z_SB(:,:,n));                                         % Copying Z as calculated in baseline scenario
Z_SC_n_temp(65:67:end,:) = Z_SB(65:67:end,:,1);                             % Resetting all aluminium sales to base year values
Z_SC_n_temp(AlC,:) = Z_SC_n_temp(AlC,:) + diffS;                            % Increasing Chinese Al sales to make physical totals right
if sn == 2
    Z_SC_n_temp(1070,:) = Z_SB(1070,:,1)*((4-n)/3);                         % Linearly decreasing  NO Al output to reach 0 in 2030
    Z_SC_n_temp(AlC,:) = Z_SC_n_temp(AlC,:) +...
        (Z_SB(1070,:,1)-Z_SC_n_temp(1070,:))/...
        newsectors_basis(1).price(16)*newsectors_basis(1).price(25);        % Increasing CN Al output correspondingly
    y_SB_vector(1070,n) = y_SB_vector(1070,1)*((4-n)/3);                    % Decreasing final demand of NO Al the same way
    y_SB_vector(AlC,n) = y_SB_vector(AlC,n) +...
        (y_SB_vector(1070,1)-y_SB_vector(1070,n))/...
        newsectors_basis(1).price(16)*newsectors_basis(1).price(25);        % ..and transferring it to CN
end

Z_SC_n_temp(Z_SC_n_temp<0)=0;
A_SC = Z_SC_n_temp*inv(diag(x_SB(:,n)));                                    %   
x_SC(:,n) = inv(eye(size(A_SC,1))-A_SC)*y_SB_vector(:,n);                   % 
x_SC(x_SC<1e-6) = 1e-6;
Z_SC_n = A_SC*diag(x_SC(:,n));                                              % 

% Trade flows:
for i = 1:31
    for j = 1:31
        trade_SC(i,j,n) = sum(Z_SC_n(67*(i-1)+65,67*(j-1)+1:67*j))/...
            (newsectors_basis(1).price(i)/1000);
    end
end

% Emissions in Scenario 1:
E_SC_pu_fd = diag(Cs(1,:))*inv(eye(size(A_SC,1))-A_SC);
E_SC_pu_fd_f(:,:,n) =...
    E_SC_pu_fd(:,[65:3*31+64]+(67-3)*floor([0:3*31-1]/3));
e_SC(:,n) = Cs*x_SC(:,n);
E_SC_dir(:,n) = diag(Cs(1,:))*x_SC(:,n);
E_SC_Z_n = diag(Cs(1,:))*Z_SC_n;
E_SC_Z_f(1:2077,1:31*3,n) =...
    E_SC_Z_n(:,[65:3*31+64]+(67-3)*floor([0:3*31-1]/3));
clear diff* n Z_SC_n_temp E_SC_Z_n E_SC_pu_fd %Z_SC_n A_SC
end
E_SC_dir(:,1) = diag(Cs(1,:))*x_SB(:,1);
e_SC(:,1)=e(:,1);

% Emissions due to Al production:
% y_Al = zeros(2077,4);
y_Al(65:67:end,:) = x_SC(65:67:end,:); %y_Al is a 'f.d.' vector containing only the total output of Al
% L_Al = L;
% L_Al(:,65:67:end) = L_Al(:,65:67:end)*inv(diag(diag(L(65:67:end,65:67:end))));
for i = 1:4
    x_Al(:,i) = L_Al*y_Al(:,i);
end
GWP_Al_SC = diag(Cs(1,:))*x_Al;
GWP_Al_SC(:,1) = GWP_Al_BL(:,1);
AP_Al_SC = diag(Cs(2,:))*x_Al;
AP_Al_SC(:,1) = AP_Al_BL(:,1);

%%





















%% Ending timer:
diff = clock-t1;
secs = diff(4)*3600+diff(5)*60+diff(6);
mins = floor(secs/60);
secs = round(secs-mins*60);
disp(['Analysis completed in ' num2str(mins) ' minutes and ' num2str(secs) ' seconds.']);
clear diff secs mins t1 i
disp('Why?');
why

%% Clearing unnecessary variables..
% clearex('A','S','S_fc','V','Y','Z','newsectors','newsectors_basis',...
%     'regions','stressors','s','v','X','L','y','x','e',...
%     'y_timeseries','x_timeseries','e_timeseries')

%% Export results to Excel
% write_results