% This script bridges the S matrices from namea sectors to eurostat.
% It takes in an Excel file with emissions for all EU countries with
% various aggregation levels, and another Excel file that contains a bridge
% for each of those emission matrices, in order to make them uniform.

%% Import

% input files
data_file = '\Stressors\Big_xls_sheet_with_stressors.xls';          % file containing the emissions (EU23)
bridge_file = '\Stressors\namea_disag.xls';                         % file containing the bridges (EU23)

[aasa,Country_Codes] = xlsread(data_file, 'Status', 'B4:B26');      % country codes
[aasa, Sector_Names] = xlsread(bridge_file, 'bridge_AT', 'B1:BI1'); % sector names
[aasa, Stressor_Names] = xlsread(data_file, 'AT', 'C3:J3');         % stressor names
Stressor_Names = Stressor_Names';
clear aasa

Sector_Names(1,60) = {'Households Direct Emissions (EP_HOUS)'};     % the 60th sector is not an industry sector, but part of final demand

n = size(Country_Codes,1);                                          % number of original countries (23)
st = size(Stressor_Names,1);                                        % number of stressors (8)
sc = size(Sector_Names,2);                                          % number of original sectors (60)       

%% Bridging, constructing S [8 stressors x (23x60) region-sectors]

for i=1:n
    
    worksheet_bridge = char(strcat('bridge_',Country_Codes(i)));    % getting the name of the bridge sheet from which we want to import
    worksheet_data = char(Country_Codes(i));                        % same as above, but for the emissions datasheet
    
    bridge = xlsread(bridge_file, worksheet_bridge, 'B2:BI99');     % this is the bridge for country i
    
    [s_rows,s_cols] = size(bridge);                                 % reading dimensions of bridge
    
    S_NAMEA = xlsread(data_file, worksheet_data,...                 % these are the unbridged emissions of country i
        strcat('C4:J',num2str(s_rows+3)))';
    
    S_esa = S_NAMEA * bridge;                                       % bridging..
    
    S_orig(1:st,sc*(i-1)+1:sc*i) = S_esa;                           % storing bridged emissions in the correct place in the new matrix
    
end

%% Now adjusting size of S
n_n  = n+8;                                                             % total number of regions should be 31 (8 ROW regions)
S_orig(1:st,sc*n+1:sc*(n_n))=0;  %NB!                                   % making room for ROW emissions (set to 0)                                         
S_fc = S_orig(:,60:60:1860);                                            % extracting household emissions
sc_n = sc-1;                                                            % total number of sectors should now be 59, when hh is extracted

for i=1:n_n
    S(:,sc_n*(i-1)+1:sc_n*i)=S_orig(:,sc*(i-1)+1:sc*i-1);               % loop to remove household emissions from S
end

%% Exporting results
save 'S_esa' S        % S [8 x (31x59)]
save 'S_fc' S_fc  % S_households [8 x 31]