function [Z,Y] = addummyscts(Z_ROW,Y_ROW,regs,scts)
%Author: Kjartan Steen-Olsen

EUregs = 23;                                                                % Number of regions in EU
ROWregs = 8;                                                                % --"--                ROW
ROWscts = 62;                                                               % --"--     sectors in ROW
Ycols = 4*EUregs+1;                                                         % --"--     columns in Y (93)
k = EUregs*scts;                                                            % 1472 - border between EU and ROW

Z = zeros(regs*scts,regs*scts);                                             % Desired dimension: 1984x1984
Y = zeros(regs*scts,Ycols);                                                 % --"--            : 1984x93

Z(1:k,1:k) = Z_ROW(1:k,1:k);                                                % Upper left submatrix (1472x1472) is equal
Y(1:k,1:Ycols) = Y_ROW(1:k,:);                                              % Same goes for upper part of Y

% Loop to expand the lower left part of Z - that is, sales from ROW sectors
for i = 1:ROWregs
    Z(k+scts*(i-1)+1:k+scts*i-2,1:k) =...
        Z_ROW(k+ROWscts*(i-1)+1:k+ROWscts*i,1:k);                           % Adding two extra dummy rows for each region (at the end)
    Y(k+scts*(i-1)+1:k+scts*i-2,:) =...
        Y_ROW(k+ROWscts*(i-1)+1:k+ROWscts*i,:);
end

% Loop to expand the upper right part of Z - that is, purchases made by ROW
% sectors..
for i = 1:ROWregs
    Z(1:k,k+scts*(i-1)+1:k+scts*i-2) =...
        Z_ROW(1:k,k+ROWscts*(i-1)+1:k+ROWscts*i);
end

% Loop to expand the lower right part of Z. This is the tricky part, with
% sales from ROW sectors to other ROW sectors. For each submatrix
% representing sales from ROW-region i to ROW-region j, two extra rows AND
% two extra columns (all zero) should be added, increasing the dimension
% from 62x62 to 64x64.
for i = 1:ROWregs
    for j = 1:ROWregs
        Z(k+scts*(i-1)+1:k+scts*i-2,k+scts*(j-1)+1:k+scts*j-2) =...
            Z_ROW(k+ROWscts*(i-1)+1:k+ROWscts*i,k+ROWscts*(j-1)+1:k+ROWscts*j);
    end
end