% Script to distribute total emissions for each country to the various
% electricity sources
%
% Author: Kjartan Steen-Olsen

elmixfile = '\Stressors\Electricity_mix_data_from_Eurostat.xls';

load('S_esa.mat')                                      % Loading original stressor matrix (59 sectors)
load('el_char.mat')                                    % See below
C = S_el_char;                                         % Matrix [stressors x regions and el sources] of emissions per kWh of various electricity sources
M = xlsread(elmixfile,'Sheet1','B16:G46');             % Matrix [regions x el sources] of electricity mix for all the regions

reg = size(M,1);                                       % Number of regions (31)
str = size(S,1);                                       % Number of stressors (8)
src = size(M,2);                                       % Number of electricity sources (6)
sc_old = size(S,2)/reg;                                % Number of original sectors (59)
sc_new = sc_old+src-1;                                 % Number of new sectors (after disaggregating electricity) (64)
el = 32;                                               % Sector number of electricity

S_el = S(:,el:sc_old:sc_old*(reg-1)+el);               % Matrix [stressors x regions] of emissions from the aggregated "electricity" sector for all regions

% Distributing electricity emissions across the new electricity sectors for all regions
for i = 1:reg
    hest = C(1:str,src*(i-1)+1:src*i);                 % emissions/kWh for all el sources for country i, according to SimaPro
    elg = hest*diag(M(i,:));                           % total emissions for each el source for country i
    sau = diag(sum(elg,2));                            % total el related emissions for country i
    for j=1:size(sau,1)
        if sau(j,j) < 1e-4
            sau(j,j) = 1e-4;
        end
    end
    gris = inv(sau)*elg;                               % transforming into emissions shares for each stressor and el source for country i
    %gris(isnan(gris))=0;
    alloc(1:str,src*(i-1)+1:src*i) = diag(S_el(:,i))*gris;  % distributing known emissions/M electricity for country i, according to shares calculated above
end

% Loop to expand S to include the new electricity sectors..
S_eldisag = zeros(str,sc_new*reg);
for i = 1:reg
    S_eldisag(:,sc_new*(i-1)+1:sc_new*(i-1)+el-1) = S(:,sc_old*(i-1)+1:sc_old*(i-1)+el-1);   % Sectors 1-31
    S_eldisag(:,sc_new*(i-1)+el:sc_new*(i-1)+el+src-1) = alloc(:,src*(i-1)+1:src*i);         % Sectors 32-37 (el)
    S_eldisag(:,sc_new*(i-1)+el+src:sc_new*i) = S(:,sc_old*(i-1)+el+1:sc_old*i);             % Sectors 38-64
end

save 'S_eldisag' S_eldisag