function [A_new,s_new,Z_new,Y_new,V_new,S_new] = makeff(A_old,s_old,Z_old,Y_old,V_old,S_old,basis,info,regs,scts)
%Author: Kjartan Steen-Olsen

A_new = A_old;
s_new = s_old;
Z_new = Z_old;
Y_new = Y_old;
V_new = V_old;
S_new = S_old;

%% A and s updating..
%Reading foreground A (in physical units - ton/ton)
NO = xlsread(info,'A_ff','D23:F25');
EU = xlsread(info,'A_ff','I23:K25');
ROW = xlsread(info,'A_ff','N23:P25');

%Reading foreground emissions (in physical units - ton/ton)
sNO = xlsread(info,'A_ff','D27:E34');
sNO(1,1)=NaN;                                                               %These should be NaN, but were set to 0 in the excel file to enable the whole array to be read
sEU = xlsread(info,'A_ff','I27:J34');
sEU(1,1)=NaN;
sROW = xlsread(info,'A_ff','N27:O34');
sROW(1,1)=NaN;

EUregs = 23;                                                                % Number of regions in Europe
N = 16;                                                                     % Region number of Norway
NA = 27;                                                                    % Region --"--     North America
SA = 28;                                                                    % Region --"--     South America

%EU23 countries..
temp = isnan(sEU);                                                          % Matrix that indicates which stressors we do not have external info on in the foreground system
sEU(isnan(sEU)) = 0;                                                        % NaN (i.e. no external data) elements in the imported matrix of emissions are set to zero
for i=1:EUregs
    A_new(scts*i-2,scts*i-2) = EU(1,1);                                     % Aluminium input is assumed to come from domestic production
    A_new(scts*NA-1,scts*i-2) = EU(2,1)/2*basis(2).price(NA)/basis(1).price(i); % Alumina input to aluminium assumed to come half from North America
    A_new(scts*SA-1,scts*i-2) = EU(2,1)/2*basis(2).price(SA)/basis(1).price(i); % ..and half from South America
    A_new(scts*i,scts*i-1) = EU(3,2)*basis(3).price(i)/basis(1).price(i);     % Alumina refineries are assumed to buy their bauxite domestically
    s_new(:,scts*i-2:scts*i-1) = s_old(:,scts*i-2:scts*i-1).*temp +...
        sEU*inv(diag([basis(1).price(i),basis(2).price(i)]/1e6));           % The 'old' emission values are set to zero if external data exists, and changed to these data. If not, the old data are kept.
end

%ROW regions..
temp = isnan(sROW);
sROW(isnan(sROW)) = 0;
for i=EUregs+1:regs
    A_new(scts*i-2,scts*i-2) = ROW(1,1);                                    % Aluminium input is assumed to come from domestic production
    A_new(scts*i-1,scts*i-2) = ROW(2,1)*basis(2).price(i)/basis(1).price(i);  % Alumina input to aluminium smelters assumed to have domestic origin
    A_new(scts*i,scts*i-1)   = ROW(3,2)*basis(3).price(i)/basis(1).price(i);  % Alumina refineries are assumed to buy their bauxite domestically
    s_new(:,scts*i-2:scts*i-1) = s_old(:,scts*i-2:scts*i-1).*temp +...
        sROW*inv(diag([basis(1).price(i),basis(2).price(i)]/1e6));            % The 'old' emission values are set to zero if external data exists, and changed to these data. If not, the old data are kept.
end

% Middle East and Africa: No alumina output
A_new(1741,2008) = A_new(2009,2008);                                        % Assuming the Middle East gets alumina from Asia
A_new(2009,2008) = 0;
A_new(1875,2075) = A_new(2076,2075);                                        % Assuming Africa gets alumina from South America
A_new(2076,2075) = 0;


%Norway..
temp = isnan(sNO);
sNO(isnan(sNO)) = 0;
    A_new(scts*N-2,scts*N-2) = NO(1,1);                                       % Aluminium input is assumed to come from domestic production
    A_new(scts*NA-1,scts*N-2) = NO(2,1)/2*basis(2).price(NA)/basis(1).price(N); % Alumina input to aluminium assumed to come half from North America
    A_new(scts*SA-1,scts*N-2) = NO(2,1)/2*basis(2).price(SA)/basis(1).price(N); % ..and half from South America
    A_new(scts*N,scts*N-1) = NO(3,2)*basis(3).price(N)/basis(1).price(N);     % Alumina refineries are assumed to buy their bauxite domestically
    s_new(:,scts*N-2:scts*N-1) = s_old(:,scts*N-2:scts*N-1).*temp +...
        sNO*inv(diag([basis(1).price(N),basis(2).price(N)]/1e6));             % The 'old' emission values are set to zero if external data exists, and changed to these data. If not, the old data are kept.

% Removing original inputs from basic metals to aluminium and from mining
% to alumina, because this is now accounted for in the foreground system:
for i=1:EUregs
    A_new(scts*(i-1)+21,65:67:end) = 0;
    A_new(scts*(i-1)+7,66:67:end) = 0;
end
for i=EUregs+1:31
    A_new(scts*(i-1)+36,65:67:end) = 0;
    A_new(scts*(i-1)+18,66:67:end) = 0;
end
    
%% Electricity:
elprices = xlsread(info,'El-prices','B3:AF3');                              % /kWh for each region
cons = 15;                                                                  % kWh/kg Al (Assuming 15 MWh el consumed per ton of Al output)

AlEl = A_old([32:6*23+31]+(67-6)*floor([0:6*23-1]/6),65:67:end);            % Matrix of all electricity inputs to the aluminium sectors of all regions ( el/ Al)
AlEl(23*6+1:31*6,:) = A_old([1584:6*8+1583]+(67-6)*floor([0:6*8-1]/6),65:67:end);

Elinp0 = sum(AlEl);                                                         % Total electricity input per alu output for all regions (/)
Elinp1 = Elinp0.*basis(1).price;                                            % Same as above, in /ton Al
Elinp2 = Elinp1./(elprices*1000);                                           % Same as above, in MWh/ton Al

diff = cons*ones(1,31);
diff(find(Elinp2<cons&Elinp2>0)) = diff(find(Elinp2<cons&Elinp2>0)) -...
    Elinp2(find(Elinp2<cons&Elinp2>0));                                     % Difference compared to the desired intensity of 15 MWh/ton Al
diff(diff==cons) = 0;
diff = (diff.*(elprices*1000))./basis(1).price;                             % Converting the vector of difference back to  el/ Al

Elinp0(Elinp0==0) = 1e-6;                                                   % To avoid problems in next line..
Elinp_dsb = AlEl*inv(diag(Elinp0));                                         % Source distribution of el inputs (each column should sum up to 1)

result = Elinp_dsb*diag(diff);                                              % The amount that should be added to the Alu columns and subtracted from the b.m. columns

% Now inserting results:
A_new([32:6*23+31]+(67-6)*floor([0:6*23-1]/6),65:67:end) =...               % Add el to Al from EU
    A_old([32:6*23+31]+(67-6)*floor([0:6*23-1]/6),65:67:end) + result(1:23*6,:);
A_new([1584:6*8+1583]+(67-6)*floor([0:6*8-1]/6),65:67:end) =...             % Add el to Al from ROW
    A_old([1584:6*8+1583]+(67-6)*floor([0:6*8-1]/6),65:67:end) + result(23*6+1:31*6,:);

%% Fixing transport costs
% Using the assumption above, together with the following assumptions:
% Needed sea transport:     16.2e3 tkm per ton Al output
% Price of sea transport:   0.01  per tkm
% Price of aluminium:       1680.9  per ton
% i.e. for Norway: 16.2e3*0.01/1680.9 = 0.096  transport per  Al output

stEU = 45;                                                                  % EU  sector number of sea transport
stRW = 54;                                                                  % ROW --"--

for i = 1:EUregs %Only EU regions have long shipping distances for alumina
    tcosts_org = sum(A_new(stEU:scts:scts*EUregs,scts*i-2)) +...
        sum(A_new(scts*EUregs+stRW:scts:end,scts*i-2));                     %Total  of sea transport per  Al output
    
    diff2 = 16.2e3*0.01/basis(1).price(i)-tcosts_org;
    
    if diff2 > 0
        A_new(scts*(SA-1)+stRW,scts*i-2) = diff2/2;                         % Half of the alumina comes from South America,
        A_new(scts*(NA-1)+stRW,scts*i-2) = diff2/2;                         % the other half from North America
    end
end

